==> istio-model-v1beta1-6.1.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashFluentImpl<A extends LoadBalancerSettingsConsistentHashFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashFluent<A>{
  public LoadBalancerSettingsConsistentHashFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashFluentImpl(LoadBalancerSettingsConsistentHash instance) {
    this.withConsistentHash(instance.getConsistentHash()); 
  }
  private LoadBalancerSettingsConsistentHashLBBuilder consistentHash;
  
  /**
   * This method has been deprecated, please use method buildConsistentHash instead.
   * @return The buildable object.
   */
  @Deprecated
  public LoadBalancerSettingsConsistentHashLB getConsistentHash() {
    return this.consistentHash!=null ?this.consistentHash.build():null;
  }
  public LoadBalancerSettingsConsistentHashLB buildConsistentHash() {
    return this.consistentHash!=null ?this.consistentHash.build():null;
  }
  public A withConsistentHash(LoadBalancerSettingsConsistentHashLB consistentHash) {
    _visitables.get("consistentHash").remove(this.consistentHash);
    if (consistentHash!=null){ this.consistentHash= new LoadBalancerSettingsConsistentHashLBBuilder(consistentHash); _visitables.get("consistentHash").add(this.consistentHash);} else { this.consistentHash = null; _visitables.get("consistentHash").remove(this.consistentHash); } return (A) this;
  }
  public Boolean hasConsistentHash() {
    return this.consistentHash != null;
  }
  public LoadBalancerSettingsConsistentHashFluent.ConsistentHashNested<A> withNewConsistentHash() {
    return new LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNestedImpl();
  }
  public LoadBalancerSettingsConsistentHashFluent.ConsistentHashNested<A> withNewConsistentHashLike(LoadBalancerSettingsConsistentHashLB item) {
    return new LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNestedImpl(item);
  }
  public LoadBalancerSettingsConsistentHashFluent.ConsistentHashNested<A> editConsistentHash() {
    return withNewConsistentHashLike(getConsistentHash());
  }
  public LoadBalancerSettingsConsistentHashFluent.ConsistentHashNested<A> editOrNewConsistentHash() {
    return withNewConsistentHashLike(getConsistentHash() != null ? getConsistentHash(): new LoadBalancerSettingsConsistentHashLBBuilder().build());
  }
  public LoadBalancerSettingsConsistentHashFluent.ConsistentHashNested<A> editOrNewConsistentHashLike(LoadBalancerSettingsConsistentHashLB item) {
    return withNewConsistentHashLike(getConsistentHash() != null ? getConsistentHash(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LoadBalancerSettingsConsistentHashFluentImpl that = (LoadBalancerSettingsConsistentHashFluentImpl) o;
    if (consistentHash != null ? !consistentHash.equals(that.consistentHash) :that.consistentHash != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(consistentHash,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (consistentHash != null) { sb.append("consistentHash:"); sb.append(consistentHash); }
    sb.append("}");
    return sb.toString();
  }
  class ConsistentHashNestedImpl<N> extends LoadBalancerSettingsConsistentHashLBFluentImpl<LoadBalancerSettingsConsistentHashFluent.ConsistentHashNested<N>> implements LoadBalancerSettingsConsistentHashFluent.ConsistentHashNested<N>,Nested<N>{
    ConsistentHashNestedImpl(LoadBalancerSettingsConsistentHashLB item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBBuilder(this, item);
    }
    ConsistentHashNestedImpl() {
      this.builder = new LoadBalancerSettingsConsistentHashLBBuilder(this);
    }
    LoadBalancerSettingsConsistentHashLBBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashFluentImpl.this.withConsistentHash(builder.build());
    }
    public N endConsistentHash() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashFluentImpl<A extends LoadBalancerSettingsConsistentHashFluent<A>> extends BaseFluent<A> implements LoadBalancerSettingsConsistentHashFluent<A>{
  public LoadBalancerSettingsConsistentHashFluentImpl() {
  }
  public LoadBalancerSettingsConsistentHashFluentImpl(LoadBalancerSettingsConsistentHash instance) {
    if (instance != null) {
      this.withConsistentHash(instance.getConsistentHash());
    }
  }
  private LoadBalancerSettingsConsistentHashLBBuilder consistentHash;
  
  /**
   * This method has been deprecated, please use method buildConsistentHash instead.
   * @return The buildable object.
   */
  @Deprecated
  public LoadBalancerSettingsConsistentHashLB getConsistentHash() {
    return this.consistentHash!=null ?this.consistentHash.build():null;
  }
  public LoadBalancerSettingsConsistentHashLB buildConsistentHash() {
    return this.consistentHash!=null ?this.consistentHash.build():null;
  }
  public A withConsistentHash(LoadBalancerSettingsConsistentHashLB consistentHash) {
    _visitables.get("consistentHash").remove(this.consistentHash);
    if (consistentHash!=null){ this.consistentHash= new LoadBalancerSettingsConsistentHashLBBuilder(consistentHash); _visitables.get("consistentHash").add(this.consistentHash);} else { this.consistentHash = null; _visitables.get("consistentHash").remove(this.consistentHash); } return (A) this;
  }
  public Boolean hasConsistentHash() {
    return this.consistentHash != null;
  }
  public LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNested<A> withNewConsistentHash() {
    return new LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNestedImpl();
  }
  public LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNested<A> withNewConsistentHashLike(LoadBalancerSettingsConsistentHashLB item) {
    return new LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNestedImpl(item);
  }
  public LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNested<A> editConsistentHash() {
    return withNewConsistentHashLike(getConsistentHash());
  }
  public LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNested<A> editOrNewConsistentHash() {
    return withNewConsistentHashLike(getConsistentHash() != null ? getConsistentHash(): new LoadBalancerSettingsConsistentHashLBBuilder().build());
  }
  public LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNested<A> editOrNewConsistentHashLike(LoadBalancerSettingsConsistentHashLB item) {
    return withNewConsistentHashLike(getConsistentHash() != null ? getConsistentHash(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashFluentImpl that = (LoadBalancerSettingsConsistentHashFluentImpl) o;
    if (!java.util.Objects.equals(consistentHash, that.consistentHash)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(consistentHash,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (consistentHash != null) { sb.append("consistentHash:"); sb.append(consistentHash); }
    sb.append("}");
    return sb.toString();
  }
  class ConsistentHashNestedImpl<N> extends LoadBalancerSettingsConsistentHashLBFluentImpl<LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNested<N>> implements LoadBalancerSettingsConsistentHashFluentImpl.ConsistentHashNested<N>,Nested<N>{
    ConsistentHashNestedImpl(LoadBalancerSettingsConsistentHashLB item) {
      this.builder = new LoadBalancerSettingsConsistentHashLBBuilder(this, item);
    }
    ConsistentHashNestedImpl() {
      this.builder = new LoadBalancerSettingsConsistentHashLBBuilder(this);
    }
    LoadBalancerSettingsConsistentHashLBBuilder builder;
    public N and() {
      return (N) LoadBalancerSettingsConsistentHashFluentImpl.this.withConsistentHash(builder.build());
    }
    public N endConsistentHash() {
      return and();
    }
    
  }
  
}
